@@ -19,7 +19,7 @@
 ;;;
 #+cmu
 (ext:file-comment
-  "$Header$")
+  "$Header: /home/CVS-cmucl/src/clx/attributes.lisp,v 1.6 1999/03/16 23:37:36 pw Exp $")
 
 ;;;	The special variable *window-attributes* is an alist containg:
 ;;;	(drawable attributes attribute-changes geometry geometry-changes)
@@ -352,8 +352,6 @@
 	(t (x-type-error background '(or (member :none :parent-relative) integer pixmap))))
   background)
 
-#+Genera (eval-when (compile) (compiler:function-defined 'window-background))
-
 (defsetf window-background set-window-background)
 
 (defun set-window-border (window border)
@@ -367,8 +365,6 @@
 	(t (x-type-error border '(or (member :copy) integer pixmap))))
   border)
 
-#+Genera (eval-when (compile) (compiler:function-defined 'window-border))
-
 (defsetf window-border set-window-border)
 
 (defun window-bit-gravity (window)
@@ -634,8 +630,6 @@
       (change-drawable-geometry window 5 (encode-type window sibling))))
   mode)
 
-#+Genera (eval-when (compile) (compiler:function-defined 'window-priority))
-
 (defsetf window-priority (window &optional sibling) (mode)
   ;; A bit strange, but retains setf form.
   `(set-window-priority ,mode ,window ,sibling))
