@@ -19,7 +19,7 @@
 ;;;
 #+cmu
 (ext:file-comment
-  "$Header$")
+  "$Header: /home/CVS-cmucl/src/clx/text.lisp,v 1.6 1999/03/16 23:37:49 pw Exp $")
 
 (in-package :xlib)
 
@@ -34,8 +34,6 @@
 ;; returned.
 
 (deftype translation-function ()
-  #+explorer t
-  #-explorer
   '(function (sequence array-index array-index (or null font) vector array-index)
 	     (values array-index (or null int16 font) (or null int32))))
 
@@ -113,10 +111,7 @@
   (declare (type sequence sequence)
 	   (type (or font gcontext) font))
   (declare (type (or null translation-function) translate)
-	   #+clx-ansi-common-lisp
-	   (dynamic-extent translate)
-	   #+(and lispm (not clx-ansi-common-lisp))
-	   (sys:downward-funarg #+Genera * #-Genera translate))
+	   (dynamic-extent translate))
   (declare (clx-values width ascent descent left right
 		  font-ascent font-descent direction
 		  (or null array-index)))
@@ -220,10 +215,7 @@
 	   (type array-index start)
 	   (type (or null array-index) end))
   (declare (type (or null translation-function) translate)
-	   #+clx-ansi-common-lisp
-	   (dynamic-extent translate)
-	   #+(and lispm (not clx-ansi-common-lisp))
-	   (sys:downward-funarg #+Genera * #-Genera translate))
+	   (dynamic-extent translate))
   (declare (clx-values integer (or null integer)))
   (when (type? font 'gcontext)
     (force-gcontext-changes font)
@@ -464,10 +456,7 @@
 	   (type (or null int32) width)
 	   (type index-size size))
   (declare (type (or null translation-function) translate)
-	   #+clx-ansi-common-lisp
-	   (dynamic-extent translate)
-	   #+(and lispm (not clx-ansi-common-lisp))
-	   (sys:downward-funarg #+Genera * #-Genera translate))
+	   (dynamic-extent translate))
   (declare (clx-values generalized-boolean (or null int32)))
   (let* ((display (gcontext-display gcontext))
 	 (result t)
@@ -515,10 +504,7 @@
 	   (type (or null int32) width)
 	   (type index-size size))
   (declare (type (or null translation-function) translate)
-	   #+clx-ansi-common-lisp
-	   (dynamic-extent translate)
-	   #+(and lispm (not clx-ansi-common-lisp))
-	   (sys:downward-funarg #+Genera * #-Genera translate))
+	   (dynamic-extent translate))
   (declare (clx-values (or null array-index) (or null int32)))
   (unless end (setq end (length sequence)))
   (ecase size
@@ -539,10 +525,7 @@
 	   (type (or null int32) width))
   (declare (clx-values (or null array-index) (or null int32)))
   (declare (type translation-function translate)
-	   #+clx-ansi-common-lisp
-	   (dynamic-extent translate)
-	   #+(and lispm (not clx-ansi-common-lisp))
-	   (sys:downward-funarg translate)) 
+	   (dynamic-extent translate)) 
   (let* ((src-start start)
 	 (src-end (or end (length sequence)))
 	 (next-start nil)
@@ -642,10 +625,7 @@
 	   (type (or null int32) width))
   (declare (clx-values (or null array-index) (or null int32)))
   (declare (type translation-function translate)
-	   #+clx-ansi-common-lisp
-	   (dynamic-extent translate)
-	   #+(and lispm (not clx-ansi-common-lisp))
-	   (sys:downward-funarg translate))
+	   (dynamic-extent translate))
   (let* ((src-start start)
 	 (src-end (or end (length sequence)))
 	 (next-start nil)
@@ -745,10 +725,7 @@
 	   (type (or null int32) width)
 	   (type index-size size))
   (declare (type (or null translation-function) translate)
-	   #+clx-ansi-common-lisp
-	   (dynamic-extent translate)
-	   #+(and lispm (not clx-ansi-common-lisp))
-	   (sys:downward-funarg #+Genera * #-Genera translate))
+	   (dynamic-extent translate))
   (declare (clx-values generalized-boolean (or null int32)))
   (let* ((display (gcontext-display gcontext))
 	 (result t)
@@ -801,10 +778,7 @@
 	   (type (or null int32) width)
 	   (type index-size size))
   (declare (type (or null translation-function) translate)
-	   #+clx-ansi-common-lisp
-	   (dynamic-extent translate)
-	   #+(and lispm (not clx-ansi-common-lisp))
-	   (sys:downward-funarg #+Genera * #-Genera translate))
+	   (dynamic-extent translate))
   (declare (clx-values (or null array-index) (or null int32)))
   (setf end (index-min (index+ start 255) (or end (length sequence))))
   (ecase size
@@ -829,10 +803,7 @@
 	   (type (or null array-index) end)
 	   (type (or null int32) width)) 
   (declare (type (or null translation-function) translate)
-	   #+clx-ansi-common-lisp
-	   (dynamic-extent translate)
-	   #+(and lispm (not clx-ansi-common-lisp))
-	   (sys:downward-funarg translate))
+	   (dynamic-extent translate))
   (declare (clx-values (or null array-index) (or null int32)))
   (do* ((display (gcontext-display gcontext))
 	(length (index- end start))
@@ -895,10 +866,7 @@
 	   (type (or null array-index) end)
 	   (type (or null int32) width))
   (declare (type (or null translation-function) translate)
-	   #+clx-ansi-common-lisp
-	   (dynamic-extent translate)
-	   #+(and lispm (not clx-ansi-common-lisp))
-	   (sys:downward-funarg translate))
+	   (dynamic-extent translate))
   (declare (clx-values (or null array-index) (or null int32)))
   (do* ((display (gcontext-display gcontext))
 	(length (index- end start))
