@@ -52,7 +52,7 @@
 	   ;;pw-- "unix" is a signal to the connect_to_inet C code
 	   ;;     to open an AF_UNIX socket instead of an AF_INET one.
 	   ;;     This is supposed to be faster on a local server.
-	   (host-name "unix")
+	   (host-name "") ;; PVE "" works better...
 	   (auth-name nil)
 	   (auth-data nil)
 	   (display-num nil)
