@@ -5,7 +5,7 @@
 ;;; Carnegie Mellon University, and has been placed in the public domain.
 ;;;
 (ext:file-comment
-  "$Header: /home/CVS-cmucl/src/code/error.lisp,v 1.52 1998/08/14 07:16:58 dtc Exp $")
+  "$Header: /home/CVS-cmucl/src/code/error.lisp,v 1.54 1999/01/09 11:12:17 dtc Exp $")
 ;;;
 ;;; **********************************************************************
 ;;;
@@ -20,7 +20,8 @@
 
 (in-package "KERNEL")
 (export '(layout-invalid condition-function-name simple-control-error
-	  simple-file-error simple-program-error simple-style-warning))
+	  simple-file-error simple-program-error simple-style-warning
+	  simple-undefined-function))
 
 (in-package "LISP")
 (export '(break error warn cerror
@@ -524,19 +525,15 @@
 		  (class
 		   (error 'simple-type-error
 			  :datum thing
-			  :expected-time 'condition-class
-			  :format-control
-			  "~S is not a condition class."
-			  :format-arguments
-			  (list thing)))
+			  :expected-type 'condition-class
+			  :format-control "~S is not a condition class."
+			  :format-arguments (list thing)))
 		  (t
 		   (error 'simple-type-error
 			  :datum thing
-			  :expected-time 'condition-class
-			  :format-control
-			  "Bad thing for class arg:~%  ~S"
-			  :format-arguments
-			  (list thing)))))
+			  :expected-type 'condition-class
+			  :format-control "Bad thing for class arg:~%  ~S"
+			  :format-arguments (list thing)))))
 	 (res (make-condition-object args)))
     (setf (%instance-layout res) (class-layout class))
     ;;
@@ -915,19 +912,19 @@
 	     (stream-error-stream condition)))))
 
 (define-condition file-error (error)
-  ((pathname :reader file-error-pathname :initarg :pathname))
+  ((pathname :reader file-error-pathname :initarg :pathname)))
+
+;;; INTERNAL
+(define-condition simple-program-error (simple-condition program-error)())
+(define-condition simple-control-error (simple-condition control-error)())
+
+(define-condition simple-file-error (simple-condition file-error) ()
   (:report
    (lambda (condition stream)
      (format stream "~&~@<File-error in function ~S:  ~3i~:_~?~:>"
 	     (condition-function-name condition)
-	     (serious-condition-format-control condition)
-	     (serious-condition-format-arguments condition)))))
-  
-
-;;; INTERNAL
-(define-condition simple-file-error    (simple-condition file-error)())
-(define-condition simple-program-error (simple-condition program-error)())
-(define-condition simple-control-error (simple-condition control-error)())
+	     (simple-condition-format-control condition)
+	     (simple-condition-format-arguments condition)))))
 
 (define-condition package-error (error)
   ((package :reader package-error-package :initarg :package)))
@@ -951,6 +948,9 @@
 	     (condition-function-name condition)
 	     (cell-error-name condition)))))
 
+(define-condition simple-undefined-function (simple-condition
+					     undefined-function) ())
+
 (define-condition arithmetic-error (error)
   ((operation :reader arithmetic-error-operation :initarg :operation
 	      :initform nil)
