@@ -5,7 +5,7 @@
 ;;; Carnegie Mellon University, and has been placed in the public domain.
 ;;;
 (ext:file-comment
-  "$Header: /home/CVS-cmucl/src/code/exports.lisp,v 1.158 1998/10/04 07:37:24 dtc Exp $")
+  "$Header: /home/CVS-cmucl/src/code/exports.lisp,v 1.167 2000/01/10 14:45:14 dtc Exp $")
 ;;;
 ;;; **********************************************************************
 ;;;
@@ -170,7 +170,8 @@
              "BIGNUM-ASHIFT-LEFT" "BIGNUM-ASHIFT-RIGHT" "BIGNUM-COMPARE"
              "BIGNUM-DEPOSIT-BYTE" "BIGNUM-ELEMENT-TYPE" "BIGNUM-GCD"
              "BIGNUM-INDEX" "BIGNUM-INTEGER-LENGTH" "BIGNUM-LOAD-BYTE"
-             "BIGNUM-LOGCOUNT" "BIGNUM-LOGICAL-AND" "BIGNUM-LOGICAL-IOR"
+	     "BIGNUM-LOGBITP" "BIGNUM-LOGCOUNT"
+	     "BIGNUM-LOGICAL-AND" "BIGNUM-LOGICAL-IOR"
              "BIGNUM-LOGICAL-NOT" "BIGNUM-LOGICAL-XOR" "BIGNUM-PLUS-P"
              "BIGNUM-TO-FLOAT" "BIGNUM-TRUNCATE" "BIGNUM-TYPE"
              "FLOAT-BIGNUM-RATIO" "MAKE-SMALL-BIGNUM"
@@ -219,7 +220,8 @@
              "UNIX-IOCTL" "UNIX-ISATTY" "UNIX-LINK" "UNIX-LISTEN" "UNIX-LSEEK"
              "UNIX-LSTAT" "UNIX-MKDIR" "UNIX-OPEN" "UNIX-PATHNAME" "UNIX-PID"
              "UNIX-PIPE" "UNIX-READ" "UNIX-READLINK" "UNIX-RECV" "UNIX-RENAME"
-             "UNIX-RMDIR" "UNIX-SELECT" "UNIX-SEND" "UNIX-SETPGRP"
+             "UNIX-RMDIR" "UNIX-SCHED-YIELD" "UNIX-SELECT" "UNIX-SEND"
+	     "UNIX-SETPGID" "UNIX-SETPGRP"
              "UNIX-SETREGID" "UNIX-SETREUID" "UNIX-SOCKET" "UNIX-STAT"
              "UNIX-SYMLINK" "UNIX-SYNC"
 	     "UNIX-TIMES" "UNIX-TRUNCATE" "UNIX-TTYNAME"
@@ -354,7 +356,7 @@
              "CLOSE" "CLRHASH" "CODE-CHAR" "COERCE"
              "COMPILATION-SPEED" "COMPILE" "COMPILE-FILE"
 	     "COMPILE-FILE-PATHNAME"
-             "COMPILED-FUNCTION" "COMPILED-FUNCTION-P" "COMPILER-LET"
+             "COMPILED-FUNCTION" "COMPILED-FUNCTION-P"
 	     "COMPILER-MACRO" "COMPILER-MACRO-FUNCTION" "COMPILER-MACROEXPAND"
 	     "COMPILER-MACROEXPAND-1" "COMPLEMENT" "COMPLEX"
 	     "COMPLEXP" "COMPUTE-RESTARTS" "CONCATENATE"
@@ -863,8 +865,9 @@
              "*TRACE-PRINT-LENGTH*" "*TRACE-PRINT-LEVEL*"
              "*TRACED-FUNCTION-LIST*")
             (:export "*AUTO-EVAL-IN-FRAME*" "*DEBUG-PRINT-LENGTH*"
-             "*DEBUG-PRINT-LEVEL*" "*DEBUG-PROMPT*" "*FLUSH-DEBUG-ERRORS*"
-             "*HELP-LINE-SCROLL-COUNT*" "*IN-THE-DEBUGGER*"
+             "*DEBUG-PRINT-LEVEL*" "*DEBUG-PROMPT*"
+	     "*DEBUG-READTABLE*" "*FLUSH-DEBUG-ERRORS*"
+	     "*HELP-LINE-SCROLL-COUNT*" "*IN-THE-DEBUGGER*"
              "*MAX-TRACE-INDENTATION*" "*TRACE-FRAME*" "*TRACE-PRINT-LENGTH*"
              "*TRACE-PRINT-LEVEL*" "*TRACED-FUNCTION-LIST*" "ARG" "BACKTRACE"
              "INTERNAL-DEBUG" "VAR" "*PRINT-LOCATION-KIND*"
@@ -1005,7 +1008,8 @@
 	     "*BYTE-COMPILE-DEFAULT*"
 	     "PURIFY" "MAP-APROPOS"
 	     "*BATCH-MODE*"
-	     
+	     "COMPILER-LET"
+
 	     ;; Gray streams extension.
 	     "FUNDAMENTAL-BINARY-STREAM" "FUNDAMENTAL-BINARY-INPUT-STREAM"
 	     "FUNDAMENTAL-BINARY-OUTPUT-STREAM" "FUNDAMENTAL-CHARACTER-STREAM"
@@ -1114,7 +1118,8 @@
 	   "CALL" "CALL-LOCAL" "CALL-NAMED" "CALL-OUT" "CALL-VARIABLE"
 	   "CALLEE-NFP-TN" "CALLEE-RETURN-PC-TN" "CATCH-BLOCK" "CHECK-CONS"
 	   "CHECK-FIXNUM" "CHECK-FUNCTION" "CHECK-FUNCTION-OR-SYMBOL"
-	   "CHECK-SIGNED-BYTE-32" "CHECK-SYMBOL" "CHECK-UNSIGNED-BYTE-32"
+	   "CHECK-BIGNUM" "CHECK-SIGNED-BYTE-32" "CHECK-SYMBOL"
+	   "CHECK-UNSIGNED-BYTE-32"
 	   "CLOSURE-INIT" "CLOSURE-REF" "CODE-CONSTANT-REF"
 	   "CODE-CONSTANT-SET" "CODE-INSTRUCTIONS" "COERCE-TO-FUNCTION"
 	   "COMPILE-FOR-EVAL" "COMPONENT" "COMPONENT-HEADER-LENGTH"
@@ -1422,14 +1427,13 @@
 	     "RESET-TIME" "UNPROFILE"))
 (dolist
     (name
-     '("ARRAY-RANK" "ARRAY-TOTAL-SIZE" "CHAR-INT" "FLOAT-DIGITS" "FLOAT-RADIX"
-       "PATHNAME-DEVICE" "PATHNAME-DIRECTORY" "PATHNAME-HOST" "PATHNAME-NAME"
-       "PATHNAME-TYPE" "PATHNAME-VERSION"))
+     '("ARRAY-RANK" "ARRAY-TOTAL-SIZE" "BOOLEAN" "CHAR-INT" "FLOAT-DIGITS"
+       "FLOAT-RADIX" "PATHNAME-DEVICE" "PATHNAME-DIRECTORY" "PATHNAME-HOST"
+       "PATHNAME-NAME" "PATHNAME-TYPE" "PATHNAME-VERSION"))
   (intern name "LISP"))
-(intern "BOOLEAN" "ALIEN")
 (intern "VOID" "C-CALL")
 (defpackage "KERNEL"
-  (:import-from "ALIEN" "BOOLEAN")
+  (:import-from "LISP" "BOOLEAN")
   (:import-from "C-CALL" "VOID")
   (:export "%ACOS" "%ACOSH" "%ARRAY-AVAILABLE-ELEMENTS"
 	   "%ARRAY-DATA-VECTOR" "%ARRAY-DIMENSION" "%ARRAY-DISPLACED-P"
@@ -1663,6 +1667,7 @@
 	   "MAKE-UNDEFINED-CLASS" "%COMPILER-ONLY-DEFSTRUCT"
 	   "CLASS-DIRECT-SUPERCLASSES" "MAKE-LAYOUT" "SIMPLE-CONTROL-ERROR"
 	   "SIMPLE-FILE-ERROR" "SIMPLE-PROGRAM-ERROR" "SIMPLE-STYLE-WARNING"
+	   "SIMPLE-UNDEFINED-FUNCTION"
 	   "BYTE-FUNCTION-TYPE" "SLOT-CLASS-PRINT-FUNCTION"
 	   "REDEFINE-LAYOUT-WARNING" "SLOT-CLASS" "INSURED-FIND-CLASS"
 	   "CONDITION-FUNCTION-NAME"))
@@ -1703,4 +1708,4 @@
 	   "PROCESS-WAIT" "PROCESS-WAIT-WITH-TIMEOUT" 
 	   "PROCESS-WHOSTATE" "PROCESS-YIELD" "PROCESSP" "RESTART-PROCESS" 
 	   "SHOW-PROCESSES" "STACK-GROUP-RESUME" "WITHOUT-SCHEDULING"
-	   "WITH-LOCK-HELD"))
+	   "WITH-LOCK-HELD" "WITH-TIMEOUT"))
