@@ -6,7 +6,7 @@
 ;;; Scott Fahlman or slisp-group@cs.cmu.edu.
 ;;;
 (ext:file-comment
-  "$Header: /home/CVS-cmucl/src/code/filesys.lisp,v 1.53 1998/07/16 13:30:47 pw Exp $")
+  "$Header: /home/CVS-cmucl/src/code/filesys.lisp,v 1.56 1999/06/03 15:55:49 pw Exp $")
 ;;;
 ;;; **********************************************************************
 ;;;
@@ -271,15 +271,13 @@
 	    (unless (= tail-start tail-end)
 	      (setf pieces (butlast pieces))
 	      (extract-name-type-and-version namestr tail-start tail-end)))
-	;; PVE: make sure there are no illigal characters in
-	;; the name. illigal being (code-char 0) and #\/
-	#+high-security
+	;; PVE: Make sure there are no illegal characters in the name
+	;; such as #\Null and #\/.
 	(when (and (stringp name)
-                   (find-if #'(lambda (x) (or (char= x #\null)
-					      (char= x #\/)))
+                   (find-if #'(lambda (x)
+				(or (char= x #\Null) (char= x #\/)))
 			    name))
 	  (error 'parse-error))
-	
 	;; Now we have everything we want.  So return it.
 	(values nil ; no host for unix namestrings.
 		nil ; no devices for unix namestrings.
@@ -414,7 +412,7 @@
 	(strings (if (eq version :wild)
 		     ".*"
 		     (format nil ".~D" version)))))
-    (apply #'concatenate 'simple-string (strings))))
+    (and (strings) (apply #'concatenate 'simple-string (strings)))))
 
 (defun unparse-unix-namestring (pathname)
   (declare (type pathname pathname))
@@ -530,6 +528,16 @@
 				   verify-existance function)))
 	(%enumerate-files "" pathname verify-existance function))))
 
+;;; This has been altered quite substantially.  
+
+;;; 1. :wild and :wild-inferiors were not patterns, and so are now
+;;; treated separately;
+
+;;; 2. Links to directories are no longer followed when
+;;; :wild-inferiors is being processed, due to the danger on systems
+;;; with linux and /proc filesystems infested with links to the root
+;;; directory. (Infinite loops: bad)
+
 (defun %enumerate-directories (head tail pathname verify-existance function)
   (declare (simple-string head))
   (if tail
@@ -539,7 +547,54 @@
 	   (%enumerate-directories (concatenate 'string head piece "/")
 				   (cdr tail) pathname verify-existance
 				   function))
-	  ((or pattern (member :wild :wild-inferiors))
+	  ((member :wild)
+	   (let ((dir (unix:open-dir head)))
+	     (when dir
+	       (unwind-protect
+		   (loop
+		     (let ((name (unix:read-dir dir)))
+		       (cond ((null name)
+			      (return))
+			     ((string= name "."))
+			     ((string= name ".."))
+			     (t
+			      (let ((subdir (concatenate 'string
+							 head name)))
+				;; see below for health warning
+				(when (eq (unix:unix-file-kind subdir t)
+					  :directory)
+				  (%enumerate-directories
+				   (concatenate 'string subdir "/")
+				   (cdr tail) pathname verify-existance
+				   function)))))))
+		 (unix:close-dir dir)))))	   
+	  ((member :wild-inferiors)
+	   (let ((dir (unix:open-dir head)))
+	     (when dir
+	       (unwind-protect
+		   (loop
+		     (let ((name (unix:read-dir dir)))
+		       (cond ((null name)
+			      (return))
+			     ((string= name "."))
+			     ((string= name ".."))
+			     (t ; always match 
+			      ;; warning - this depends
+			      ;; on lstat behaving in the same way on
+			      ;; different platforms. Basically,
+			      ;; lstat("foo") -> :link, lstat("foo/")
+			      ;; -> directory on linux 2.2.
+			      (let ((subdir (concatenate 'string
+							 head name)))
+				(when (eq (unix:unix-file-kind subdir t)
+					  :directory)
+				  (%enumerate-directories
+				   (concatenate 'string subdir "/")
+				   tail pathname verify-existance
+				   function)))))))
+		 (unix:close-dir dir))
+	       (%enumerate-files head pathname verify-existance	function))))
+	  (pattern
 	   (let ((dir (unix:open-dir head)))
 	     (when dir
 	       (unwind-protect
@@ -640,7 +695,10 @@
 ;;; 
 (defun unix-namestring (pathname &optional (for-input t) executable-only)
   "Convert PATHNAME into a string that can be used with UNIX system calls.
-   Search-lists and wild-cards are expanded."
+   Search-lists and wild-cards are expanded. If optional argument
+   FOR-INPUT is true and PATHNAME doesn't exist, NIL is returned.
+   If optional argument EXECUTABLE-ONLY is true, NIL is returned
+   unless an executable version of PATHNAME exists."
   ;; toy@rtp.ericsson.se: Let unix-namestring also handle logical
   ;; pathnames too.
   (let ((path (let ((lpn (pathname pathname)))
@@ -815,37 +873,217 @@
 
 ;;; DIRECTORY  --  public.
 ;;; 
-(defun directory (pathname &key (all t) (check-for-subdirs t)
-			   (follow-links t))
-  "Returns a list of pathnames, one for each file that matches the given
-   pathname.  Supplying :ALL as nil causes this to ignore Unix dot files.  This
-   never includes Unix dot and dot-dot in the result.  If :FOLLOW-LINKS is NIL,
-   then symblolic links in the result are not expanded.  This is not the
-   default because TRUENAME does follow links, and the result pathnames are
-   defined to be the TRUENAME of the pathname (the truename of a link may well
-   be in another directory.)"
-  (let ((results nil))
-    (enumerate-search-list
-	(pathname (merge-pathnames pathname
-				   (make-pathname :name :wild
-						  :type :wild
-						  :version :wild)))
-      (enumerate-matches (name pathname)
-	(when (or all
-		  (let ((slash (position #\/ name :from-end t)))
-		    (or (null slash)
-			(= (1+ slash) (length name))
-			(char/= (schar name (1+ slash)) #\.))))
-	  (push name results))))
-    (let ((*ignore-wildcards* t))
-      (mapcar #'(lambda (name)
-		  (let ((name (if (and check-for-subdirs
-				       (eq (unix:unix-file-kind name)
-					   :directory))
-				  (concatenate 'string name "/")
-				  name)))
-		    (if follow-links (truename name) (pathname name))))
-	      (sort (delete-duplicates results :test #'string=) #'string<)))))
+
+;;; modified 13/Apr/1999 csr21@cam.ac.uk Christophe Rhodes
+(defun directory (pathname &key (all t) (check-for-subdirs nil) (delete-duplicates nil) (follow-links nil) (resolve-links nil) (sort nil))
+  "Returns a list of pathnames, one for each file that matches the
+given pathname. Keyword arguments:
+
+all: If false, will ignore files with names beginning with a #\\.  
+
+check-for-subdirs: If true, will check the file to see if it is
+actually a directory, and if so the resultant pathname will reflect
+such.
+
+delete-duplicates: If true, will delete duplicate pathnames in the
+result list.
+
+follow-links: if true, will treat links linked to directories as
+directories. Warning: this may cause infinite loops if a symlink
+points to an ancestor (/proc/ on Linux is a spectacular example of
+this).
+
+resolve-links: if true, will attempt to resolve links in the resultant
+list (via truename). Duplicates resulting from the resolving process
+will be removed if delete-duplicates is non-nil.
+
+sort: if true, will attempt to sort the results alphabetically."
+  ;; I don't think that this can result in any
+  ;; duplicates. Let me know if you think otherwise.
+  (let ((answer 
+	 (dir (merge-pathnames pathname 
+			       (make-pathname :name :wild
+					      :type :wild))
+	      :all all
+	      :check-for-subdirs check-for-subdirs
+	      :follow-links follow-links
+	      :sort sort)))
+    ;; If the above assertion is correct, then this one is not needed.
+    (when delete-duplicates
+      (setf answer (delete-duplicates answer :test #'string=)))
+    (setf answer
+	  (if resolve-links
+	      (mapcar #'(lambda (x)
+			  (let ((*ignore-wildcards* t))
+			    (truename (parse-namestring x))))
+		      answer)
+	    (mapcar #'(lambda (x)
+			(let ((*ignore-wildcards* t))
+			  (parse-namestring x)))
+		    answer)))
+    (when delete-duplicates
+      (setf answer (delete-duplicates answer :test #'pathname=)))
+    answer))
+
+
+(defun dir (pathname &key all check-for-subdirs follow-links sort)
+  "Returns namestrings (suitable for parse-namestring) for all files
+matching the specification of pathname."
+  (let ((directory (pathname-directory pathname)))
+    (let ((answer (loop for d in (matching-directories directory '("") :all all :follow-links follow-links :sort sort)
+			append (matching-files d pathname :all all :sort sort))))
+      (if check-for-subdirs
+	  (mapcar #'(lambda (filename) 
+		      (if (eq :directory (unix:unix-file-kind filename (not follow-links)))
+			  (concatenate 'string filename "/")
+			filename))
+		  answer)
+	answer))))
+
+(defun directory-contents (dirstring &key (all t) (ignore-dots t) sort)
+  "Return a list of all files returned by unix:read-dir in the
+directory named by dirstring. If :ignore-dots is t (the default), then
+\".\" and \"..\" are not included. If all is nil, filenames beginning
+with #\\. are removed from the results."
+  (let ((dir (unix:open-dir dirstring)))
+    (let ((result (when dir
+		    (let ((contents (unwind-protect
+					(loop when (unix:read-dir dir)
+					      collect it
+					      else do (loop-finish))
+				      (unix:close-dir dir))))
+		      (unless all
+			(setf contents 
+			      (remove-if #'(lambda (filename) 
+					     (char= (aref filename 0) #\.))
+					 contents)))
+		      (if ignore-dots
+			  (remove-if #'(lambda (f) (or (equal f ".")
+						       (equal f "..")))
+				     contents)
+			contents)))))
+      (when sort
+	(setf result (sort result #'string<)))
+      result)))
+
+;;; The logic behind some of these cases is slightly contorted, but, I
+;;; believe, correct.
+(defun matching-directories (directory &optional (result '("")) &key all follow-links sort)
+  "Return a list of strings naming all directories matching the
+directory spec. If directory is a string, pathname-directory is called
+on it."
+  (labels ((string-add (string &key endp) 
+	    #'(lambda (s) (if endp
+			      (concatenate 'string s string)
+			    (concatenate 'string string s)))))
+    (when (typep directory 'string)
+      (setf directory (pathname-directory directory)))
+    (typecase (car directory)
+      ;; no more directory -- therefore, result contains all matching
+      ;; directories.
+      (null result)
+      ;; :absolute and :relative should reset the result list.
+      ((member :absolute) (matching-directories (cdr directory) '("/")
+						:all all
+						:follow-links follow-links
+						:sort sort))
+      ((member :relative) (matching-directories (cdr directory) '("")
+						:all all
+						:follow-links follow-links
+						:sort sort))
+      ;; this one's not too hard either, since .. is always valid, and
+      ;; I don't think we should protect people against (directory
+      ;; "/../") even if it weren't -- it's their problem.
+      ((member :up) (matching-directories (cdr directory) (mapcar (string-add "../" :endp t) result) :all all :follow-links follow-links :sort sort))
+      ;; We want all the directories such that each directory
+      ;; currently in the results list is checked for subdirectories
+      ;; that match the pattern.
+      ((satisfies pattern-p)
+       (let ((directories
+	      (remove-if-not 
+	       #'(lambda (file) (eq :directory (unix:unix-file-kind file (not follow-links))))
+	       (apply #'append 
+		      (mapcar #'(lambda (d) 
+				  (mapcar (string-add d) 
+					  (remove-if-not
+					   #'(lambda (str)
+					       (pattern-matches 
+						(car directory)
+						str))
+					      (directory-contents d :all all :sort sort))))
+			      result)))))
+       (matching-directories (cdr directory) (mapcar (string-add "/" :endp t) directories) :follow-links follow-links :all all :sort sort)))
+      ;; If the first directory entry is :wild, then we want all
+      ;; directories (remove-if-not-directory) contained in all of the
+      ;; directories currently in result.
+      ((member :wild)
+       (let ((directories 
+	      (remove-if-not 
+	       #'(lambda (file) (eq :directory (unix:unix-file-kind file (not follow-links))))
+	       (apply #'append 
+		      (mapcar #'(lambda (d) 
+				  (mapcar (string-add d) (directory-contents d :all all :sort sort))) 
+			      result)))))
+	 (when directories
+	   (matching-directories (cdr directory)
+				 (mapcar (string-add "/" :endp t) directories)
+				 :follow-links follow-links :all all :sort sort))))
+      ;; (:wild-inferiors ,@foo) is equivalent to (:wild
+      ;; :wild-inferiors ,@foo) and (,@foo).  The slowness resulting
+      ;; is due to the fact that each level requires traversal of all
+      ;; previous levels. I can't think of a nice way to do this -- it
+      ;; may have to be special-cased. However, it is tolerable now, I
+      ;; believe.  Sorting has to be done here too, as we are doing a
+      ;; recursion rightwards but sorting from the left.
+      ((member :wild-inferiors)
+       (let ((temp (append (matching-directories (cons :wild directory) result :follow-links follow-links :all all :sort sort)
+			   (matching-directories (cdr directory) result :follow-links follow-links :all all :sort sort))))
+	 (when sort
+	   (setf temp (sort temp #'string<)))
+	 temp))
+      (string (matching-directories 
+	       (cdr directory)
+	       (mapcar (string-add "/" :endp t)
+		       (remove-if-not
+			#'(lambda (file) (eq :directory (unix:unix-file-kind file (not follow-links))))
+			(mapcar (string-add (car directory) :endp t) result)))
+	       :follow-links follow-links :all all :sort sort)))))
+				    
+(defun matching-files (directory pathname &key all sort)
+  "Returns a list of strings naming all files in directory matching
+the name, type and version fields of pathname."
+  (let ((name (pathname-name pathname))
+	(type (pathname-type pathname))
+	(version (pathname-version pathname)))
+    (cond
+     ((member name '(nil :unspecific)) ())
+     ;; there's still a nasty interaction here on versioned
+     ;; files. (pathname-version "/home/csr21/*") => :newest.
+     ((or (pattern-p name)
+	  (pattern-p type)
+	  (eq name :wild)
+	  (eq type :wild))
+       (loop for file in (directory-contents directory :all all :sort sort)
+	     if (multiple-value-bind
+		    (file-name file-type file-version)
+		    (let ((*ignore-wildcards* t))
+		      (extract-name-type-and-version file 0 (length file)))
+		  (and (components-match file-name name)
+		       (components-match file-type type)
+		       (components-match file-version version)))
+	     collect (concatenate 'string directory file)))
+     ;; name is a string
+     (t 
+      (let ((file (concatenate 'string directory name)))
+	(unless (or (null type) (eq type :unspecific))
+	  (setf file (concatenate 'string file "." type)))
+	(unless (member version '(nil :newest :wild))
+	  (setf file (concatenate 'string file "."
+				  (quick-integer-to-string version))))
+	;; return nil if the file doesn't exist
+	(when (unix:unix-file-kind file) (list file))))
+      )))
+		  
 
 
 ;;;; Printing directories.
@@ -1211,7 +1449,8 @@
 
 (defun filesys-init ()
   (setf *default-pathname-defaults*
-	(%make-pathname *unix-host* nil nil nil nil :newest))
+        #+:unix (%make-pathname *unix-host* nil nil nil nil :unspecific)
+	#-:unix (%make-pathname *unix-host* nil nil nil nil :newest))
   (setf (search-list "default:") (default-directory))
   nil)
 
