@@ -5,7 +5,7 @@
 ;;; Carnegie Mellon University, and has been placed in the public domain.
 ;;;
 (ext:file-comment
-  "$Header: /home/CVS-cmucl/src/code/float.lisp,v 1.18 1998/03/21 08:11:56 dtc Exp $")
+  "$Header: /home/CVS-cmucl/src/code/float.lisp,v 1.20 1999/11/19 15:12:36 dtc Exp $")
 ;;;
 ;;; **********************************************************************
 ;;;
@@ -351,7 +351,10 @@
 (defun float-radix (f)
   "Returns (as an integer) the radix b of its floating-point
    argument."
-  (declare (type float f))
+  #-high-security
+  (declare (ignore f))
+  #+high-security
+  (check-type f float)
   2)
 
 
@@ -1041,13 +1044,11 @@ rounding modes & do ieee round-to-integer.
 	    (float most-positive-fixnum number))
 	 (truly-the fixnum (%unary-round number))
 	 (multiple-value-bind (bits exp)
-			      (integer-decode-float number)
+	     (integer-decode-float number)
 	   (let* ((shifted (ash bits exp))
 		  (rounded (if (and (minusp exp)
-				    (oddp shifted)
-				    (eql (logand bits
-						 (lognot (ash -1 (- exp))))
-					 (ash 1 (- -1 exp))))
+				    (not (zerop (logand bits
+							(ash 1 (- -1 exp))))))
 			       (1+ shifted)
 			       shifted)))
 	     (if (minusp number)
@@ -1104,11 +1105,12 @@ rounding modes & do ieee round-to-integer.
 		   (den 1 (+ (* a den) oden))
 		   (onum 1 num)
 		   (oden 0 den))
-		  ((and (not (zerop den))
-			(not (> (abs (/ (- x (/ (float num x)
-						(float den x)))
-					x))
-				eps)))
+		  ((or (= xx (float a x))
+		       (and (not (zerop den))
+			    (not (> (abs (/ (- x (/ (float num x)
+						    (float den x)))
+					    x))
+                                    eps))))
 		   (integer-/-integer num den))
 		(declare ((dispatch-type x) xx)))))))
     ((rational) x)))
