@@ -5,7 +5,7 @@
 ;;; Carnegie Mellon University, and has been placed in the public domain.
 ;;;
 (ext:file-comment
-  "$Header: /home/CVS-cmucl/src/code/irrat.lisp,v 1.28 1998/04/15 01:29:57 dtc Exp $")
+  "$Header: /home/CVS-cmucl/src/code/irrat.lisp,v 1.30 1999/11/19 14:55:53 dtc Exp $")
 ;;;
 ;;; **********************************************************************
 ;;;
@@ -75,7 +75,7 @@
 #-x86 (def-math-rtn "log" 1)
 #-x86 (def-math-rtn "log10" 1)
 (def-math-rtn "pow" 2)
-#-x86 (def-math-rtn "sqrt" 1)
+#-(or x86 sparc-v7 sparc-v8 sparc-v9) (def-math-rtn "sqrt" 1)
 (def-math-rtn "hypot" 2)
 #-(or hpux x86) (def-math-rtn "log1p" 1)
 
