@@ -5,7 +5,7 @@
 ;;; Carnegie Mellon University, and has been placed in the public domain.
 ;;;
 (ext:file-comment
-  "$Header: /home/CVS-cmucl/src/code/stream.lisp,v 1.35 1998/07/24 17:17:55 dtc Exp $")
+  "$Header: /home/CVS-cmucl/src/code/stream.lisp,v 1.39 1999/02/11 12:17:58 dtc Exp $")
 ;;;
 ;;; **********************************************************************
 ;;;
@@ -375,10 +375,8 @@
 (defun peek-char (&optional (peek-type nil) (stream *standard-input*)
 			    (eof-errorp t) eof-value recursive-p)
   "Peeks at the next character in the input Stream.  See manual for details."
-  (when recursive-p
-    (setf eof-errorp t))
-  
-  (let ((stream (in-synonym-of stream)))
+  (let ((stream (in-synonym-of stream))
+	(eof-errorp (or eof-errorp recursive-p)))
     (if (lisp-stream-p stream)
 	(let ((char (read-char stream eof-errorp eof-value)))
 	  (cond ((eq char eof-value) char)
@@ -674,7 +672,8 @@
 
 (defun write-byte (integer stream)
   "Outputs the Integer to the binary Stream."
-  (with-out-stream stream (lisp-stream-bout integer) (stream-write-byte))
+  (with-out-stream stream (lisp-stream-bout integer)
+		   (stream-write-byte integer))
   integer)
 
 
@@ -1070,20 +1069,21 @@
   unread-stuff)
 
 
-(macrolet ((in-fun (name fun out-slot stream-method &rest args)
-	     `(defun ,name (stream ,@args)
+(macrolet ((in-fun (name fun out-slot stream-method)
+	     `(defun ,name (stream eof-errorp eof-value)
 		(or (pop (echo-stream-unread-stuff stream))
 		    (let* ((in (echo-stream-input-stream stream))
 			   (out (echo-stream-output-stream stream))
-			   (result (,fun in ,@args)))
-		      (if (lisp-stream-p out)
-			  (funcall (,out-slot out) out result)
-			  (,stream-method out result))
-		      result)))))
-  (in-fun echo-in read-char lisp-stream-out stream-write-char
-	  eof-errorp eof-value)
-  (in-fun echo-bin read-byte lisp-stream-bout stream-write-byte
-	  eof-errorp eof-value))
+			   (result (,fun in nil :eof)))
+		      (cond ((eq result :eof)
+			     (eof-or-lose stream eof-errorp eof-value))
+			    (t
+			     (if (lisp-stream-p out)
+				 (funcall (,out-slot out) out result)
+				 (,stream-method out result))
+			     result)))))))
+  (in-fun echo-in read-char lisp-stream-out stream-write-char)
+  (in-fun echo-bin read-byte lisp-stream-bout stream-write-byte))
 
 (defun echo-misc (stream operation &optional arg1 arg2)
   (let* ((in (two-way-stream-input-stream stream))
@@ -1213,7 +1213,8 @@
   (when (> end (length string))
     (cerror "Continue with end changed from ~s to ~s"
 	      "Write-string: end (~S) is larger then the length of the string (~S)"
-	      end (1- (length string))))
+	      end (1- (length string)))
+     (setf end (1- (length string))))
 
   (internal-make-string-input-stream (coerce string 'simple-string)
 				     start end))
