@@ -5,7 +5,7 @@
 ;;; Carnegie Mellon University, and has been placed in the public domain.
 ;;;
 (ext:file-comment
-  "$Header: /home/CVS-cmucl/src/compiler/byte-comp.lisp,v 1.26 1998/01/20 16:10:44 dtc Exp $")
+  "$Header: /home/CVS-cmucl/src/compiler/byte-comp.lisp,v 1.27 1999/02/25 13:03:00 pw Exp $")
 ;;;
 ;;; **********************************************************************
 ;;;
@@ -219,9 +219,7 @@
     return-from
     tagbody
     go
-    unwind-protect
-    dylan-var-ref
-    dylan-var-set))
+    unwind-protect))
 
 (defun xop-index-or-lose (name)
   (or (position name *xop-names* :test #'eq)
@@ -1339,13 +1337,7 @@
 		(output-do-inline-function segment 'symbol-value))
 	       (:global-function
 		(output-push-fdefinition segment (global-var-name leaf))
-		(output-do-xop segment 'fdefn-function-or-lose))))
-	    (dylan-var
-	     (output-push-load-time-constant
-	      segment :dylan-varinfo-value
-	      (cons (dylan-var-name leaf)
-		    (dylan-var-module-name leaf)))
-	     (output-do-xop segment 'dylan-var-ref)))
+		(output-do-xop segment 'fdefn-function-or-lose)))))
 	  (checked-canonicalize-values segment cont 1))))))
   (undefined-value))
 
@@ -1367,13 +1359,7 @@
 	  (output-push-constant segment (global-var-name leaf))
 	  (output-do-inline-function segment 'setf-symbol-value))))
       (lambda-var
-       (output-set-lambda-var segment leaf (node-environment set)))
-      (dylan-var
-       (output-push-load-time-constant
-	segment :dylan-varinfo-value
-	(cons (dylan-var-name leaf)
-	      (dylan-var-module-name leaf)))
-       (output-do-xop segment 'dylan-var-set)))
+       (output-set-lambda-var segment leaf (node-environment set))))
     (unless (eql values 0)
       (checked-canonicalize-values segment cont 1)))
   (undefined-value))
