@@ -5,7 +5,7 @@
 ;;; Carnegie Mellon University, and has been placed in the public domain.
 ;;;
 (ext:file-comment
-  "$Header: /home/CVS-cmucl/src/compiler/fndb.lisp,v 1.83 1998/05/29 06:41:24 dtc Exp $")
+  "$Header: /home/CVS-cmucl/src/compiler/fndb.lisp,v 1.85 1999/02/02 12:18:36 pw Exp $")
 ;;;
 ;;; **********************************************************************
 ;;;
@@ -584,13 +584,11 @@
 
 (defknown read-sequence (sequence stream &key (:start index)
 				  (:end sequence-end))
-  (index)
-  (flushable))
+  (index) ())
 
 (defknown write-sequence (sequence stream &key (:start index)
 				   (:end sequence-end))
-  (sequence)
-  ()
+  (sequence) ()
   :derive-type (sequence-result-nth-arg 1))
 
 
@@ -1007,7 +1005,7 @@
   pathname-version (flushable))
 
 (defknown (namestring file-namestring directory-namestring host-namestring)
-  (pathnamelike) simple-string
+  (pathnamelike) (or null simple-string)
   (flushable))
 
 (defknown enough-namestring (pathnamelike &optional pathnamelike)
