@@ -4,7 +4,7 @@
 ;;; Carnegie Mellon University, and has been placed in the public domain.
 ;;;
 (ext:file-comment
-  "$Header: /home/CVS-cmucl/src/compiler/generic/new-genesis.lisp,v 1.37 1998/11/26 11:46:46 dtc Exp $")
+  "$Header: /home/CVS-cmucl/src/compiler/generic/new-genesis.lisp,v 1.39 1999/09/09 16:31:08 pw Exp $")
 ;;;
 ;;; **********************************************************************
 ;;;
@@ -1835,7 +1835,10 @@
 
 ;; FreeBSD wants C language symbols prefixed with "_" including all the
 ;; syscalls and Unix library things. Linux doesn't or maybe does
-;; depending on things I don't know about yet?
+;; depending on things I don't know about yet? FreeBSD version 3
+;; is ELF based and looks more like the other systems.
+;; Maybe these x86 hacks can be fixed when the non-elf's are obsoleted.
+
 (defun lookup-maybe-prefix-foreign-symbol (name)
   (lookup-foreign-symbol
    (concatenate 'string
@@ -1852,9 +1855,10 @@
 		       ""
 		       "_"))
 		  (#.c:x86-fasl-file-implementation
-		   (if (c:backend-featurep :freebsd)
-		       "_" ; FreeBSD
-		       "")) ; Linux
+		   (if (and (c:backend-featurep :freebsd)
+			    (not (c:backend-featurep :elf)))
+		       "_" ; older FreeBSD
+		       "")) ; Linux and FreeBSD V3+
 		  )
 		name)))
 
@@ -1926,15 +1930,18 @@
        (ecase kind
 	 (:jump
 	  (assert (zerop (ash value -28)))
-	  (setf (ldb (byte 26 0) (sap-ref-32 sap 0))
-		(ash value -2)))
+	  (let ((inst (maybe-byte-swap (sap-ref-32 sap 0))))
+	    (setf (ldb (byte 26 0) inst) (ash value -2))
+	    (setf (sap-ref-32 sap 0) (maybe-byte-swap inst))))
 	 (:lui
 	  (setf (sap-ref-16 sap 0)
-		(+ (ash value -16)
-		   (if (logbitp 15 value) 1 0))))
+		(maybe-byte-swap-short
+		 (+ (ash value -16)
+		    (if (logbitp 15 value) 1 0)))))
 	 (:addi
 	  (setf (sap-ref-16 sap 0)
-		(ldb (byte 16 0) value)))))
+		(maybe-byte-swap-short
+		 (ldb (byte 16 0) value))))))
       (#.c:sparc-fasl-file-implementation
        (let ((inst (maybe-byte-swap (sap-ref-32 sap 0))))
 	 (ecase kind
@@ -2057,15 +2064,18 @@
        (ecase kind
 	 (:jump
 	  (assert (zerop (ash value -28)))
-	  (setf (ldb (byte 26 0) (sap-ref-32 sap 0))
-		(ash value -2)))
+	  (let ((inst (maybe-byte-swap (sap-ref-32 sap 0))))
+	    (setf (ldb (byte 26 0) inst) (ash value -2))
+	    (setf (sap-ref-32 sap 0) (maybe-byte-swap inst))))
 	 (:lui
 	  (setf (sap-ref-16 sap 2)
-		(+ (ash value -16)
-		   (if (logbitp 15 value) 1 0))))
+		(maybe-byte-swap-short
+		 (+ (ash value -16)
+		    (if (logbitp 15 value) 1 0)))))
 	 (:addi
 	  (setf (sap-ref-16 sap 2)
-		(ldb (byte 16 0) value)))))))
+		(maybe-byte-swap-short
+		 (ldb (byte 16 0) value))))))))
   (undefined-value))
 
 (defun linkage-info-to-core ()
