@@ -5,7 +5,7 @@
 ;;; Carnegie Mellon University, and has been placed in the public domain.
 ;;;
 (ext:file-comment
-  "$Header: /home/CVS-cmucl/src/compiler/locall.lisp,v 1.47 1998/03/01 21:55:45 dtc Exp $")
+  "$Header: /home/CVS-cmucl/src/compiler/locall.lisp,v 1.48 1999/12/03 16:28:28 dtc Exp $")
 ;;;
 ;;; **********************************************************************
 ;;;
@@ -949,7 +949,8 @@
 	       (not (functional-entry-function fun)))
       (let* ((ref-cont (node-cont (first refs)))
 	     (dest (continuation-dest ref-cont)))
-	(when (and (basic-combination-p dest)
+	(when (and dest
+		   (basic-combination-p dest)
 		   (eq (basic-combination-fun dest) ref-cont)
 		   (eq (basic-combination-kind dest) :local)
 		   (not (block-delete-p (node-block dest)))
@@ -1050,7 +1051,9 @@
 	  (call-fun nil))
       (when (and (dolist (ref (leaf-refs fun) t)
 		   (let ((dest (continuation-dest (node-cont ref))))
-		     (when (block-delete-p (node-block dest)) (return nil))
+		     (when (or (not dest)
+			       (block-delete-p (node-block dest)))
+		       (return nil))
 		     (let ((home (node-home-lambda ref)))
 		       (unless (eq home fun)
 			 (when call-fun (return nil))
