@@ -5,7 +5,7 @@
 ;;; Carnegie Mellon University, and has been placed in the public domain.
 ;;;
 (ext:file-comment
-  "$Header: /home/CVS-cmucl/src/compiler/ltn.lisp,v 1.39 1997/07/13 20:02:49 dtc Exp $")
+  "$Header: /home/CVS-cmucl/src/compiler/ltn.lisp,v 1.40 1999/02/25 13:03:09 pw Exp $")
 ;;;
 ;;; **********************************************************************
 ;;;
@@ -101,7 +101,7 @@
 	   (etypecase leaf
 	     (lambda-var (if (null (lambda-var-sets leaf)) leaf nil))
 	     (constant (if (legal-immediate-constant-p leaf) leaf nil))
-	     ((or functional global-var dylan-var) nil))))))
+	     ((or functional global-var) nil))))))
 
 
 ;;; Annotate-1-Value-Continuation  --  Internal
