@@ -11,10 +11,6 @@
 ;;;    This file contains stuff that knows about dumping code both to files to
 ;;; the running Lisp.
 ;;;
-#+cmu
-(ext:file-comment
-  "$Header$")
-
 (in-package 'c)
 
 (proclaim '(special compiler-version))
