@@ -5,13 +5,11 @@
 ;;; Carnegie Mellon University, and has been placed in the public domain.
 ;;;
 (ext:file-comment
-  "$Header: /home/CVS-cmucl/src/compiler/sparc/arith.lisp,v 1.11 1998/03/21 08:05:20 dtc Exp $")
+  "$Header: /home/CVS-cmucl/src/compiler/sparc/arith.lisp,v 1.19 2000/01/17 18:08:19 dtc Exp $")
 ;;;
 ;;; **********************************************************************
 ;;;
-;;; $Header: /home/CVS-cmucl/src/compiler/sparc/arith.lisp,v 1.11 1998/03/21 08:05:20 dtc Exp $
-;;;
-;;;    This file contains the VM definition arithmetic VOPs for the MIPS.
+;;; This file contains the VM definition arithmetic VOPs for the SPARC.
 ;;;
 ;;; Written by Rob MacLachlan
 ;;;
@@ -206,13 +204,13 @@
 
 ;;; Shifting
 
-(define-vop (fast-ash)
+(define-vop (fast-ash/unsigned=>unsigned)
   (:note "inline ASH")
-  (:args (number :scs (signed-reg unsigned-reg) :to :save)
+  (:args (number :scs (unsigned-reg) :to :save)
 	 (amount :scs (signed-reg immediate)))
-  (:arg-types (:or signed-num unsigned-num) signed-num)
-  (:results (result :scs (signed-reg unsigned-reg)))
-  (:result-types (:or signed-num unsigned-num))
+  (:arg-types unsigned-num signed-num)
+  (:results (result :scs (unsigned-reg)))
+  (:result-types unsigned-num)
   (:translate ash)
   (:policy :fast-safe)
   (:temporary (:sc non-descriptor-reg) ndesc)
@@ -226,13 +224,9 @@
 	 (inst neg ndesc amount)
 	 (inst cmp ndesc 31)
 	 (inst b :le done)
-	 (sc-case number
-	   (signed-reg (inst sra result number ndesc))
-	   (unsigned-reg (inst srl result number ndesc)))
+	 (inst srl result number ndesc)
 	 (inst b done)
-	 (sc-case number
-	   (signed-reg (inst sra result number 31))
-	   (unsigned-reg (inst srl result number 31)))
+	 (inst srl result number 31)
 
 	 (emit-label positive)
 	 ;; The result-type assures us that this shift will not overflow.
@@ -244,11 +238,44 @@
        (let ((amount (tn-value amount)))
 	 (if (minusp amount)
 	     (let ((amount (min 31 (- amount))))
-	       (sc-case number
-		 (unsigned-reg
-		  (inst srl result number amount))
-		 (signed-reg
-		  (inst sra result number amount))))
+	       (inst srl result number amount))
+	     (inst sll result number amount)))))))
+
+(define-vop (fast-ash/signed=>signed)
+  (:note "inline ASH")
+  (:args (number :scs (signed-reg) :to :save)
+	 (amount :scs (signed-reg immediate)))
+  (:arg-types signed-num signed-num)
+  (:results (result :scs (signed-reg)))
+  (:result-types signed-num)
+  (:translate ash)
+  (:policy :fast-safe)
+  (:temporary (:sc non-descriptor-reg) ndesc)
+  (:generator 3
+    (sc-case amount
+      (signed-reg
+       (let ((positive (gen-label))
+	     (done (gen-label)))
+	 (inst cmp amount)
+	 (inst b :ge positive)
+	 (inst neg ndesc amount)
+	 (inst cmp ndesc 31)
+	 (inst b :le done)
+	 (inst sra result number ndesc)
+	 (inst b done)
+	 (inst sra result number 31)
+
+	 (emit-label positive)
+	 ;; The result-type assures us that this shift will not overflow.
+	 (inst sll result number amount)
+
+	 (emit-label done)))
+
+      (immediate
+       (let ((amount (tn-value amount)))
+	 (if (minusp amount)
+	     (let ((amount (min 31 (- amount))))
+	       (inst sra result number amount))
 	     (inst sll result number amount)))))))
 
 
@@ -283,29 +310,31 @@
   (:translate logcount)
   (:note "inline (unsigned-byte 32) logcount")
   (:policy :fast-safe)
-  (:args (arg :scs (unsigned-reg) :target shift))
+  (:args (arg :scs (unsigned-reg)))
   (:arg-types unsigned-num)
-  (:results (res :scs (any-reg)))
+  (:results (res :scs (unsigned-reg)))
   (:result-types positive-fixnum)
-  (:temporary (:scs (non-descriptor-reg) :from (:argument 0)) shift temp)
-  (:generator 30
-    (let ((loop (gen-label))
-	  (done (gen-label)))
-      (inst addcc shift zero-tn arg)
-      (inst b :eq done)
-      (move res zero-tn)
+  (:temporary (:scs (non-descriptor-reg) :from (:argument 0)) mask temp)
+  (:generator 35
+      (move res arg)
 
-      (emit-label loop)
-      (inst sub temp shift 1)
-      (inst andcc shift temp)
-      (inst b :ne loop)
-      (inst add res (fixnum 1))
+      (dolist (stuff '((1 #x55555555) (2 #x33333333) (4 #x0f0f0f0f)
+		       (8 #x00ff00ff) (16 #x0000ffff)))
+	(destructuring-bind (shift bit-mask)
+	    stuff
+	  ;; Set mask
+	  (inst sethi mask (ldb (byte 22 10) bit-mask))
+	  (inst add mask (ldb (byte 10 0) bit-mask))
+
+	  (inst and temp res mask)
+	  (inst srl res shift)
+	  (inst and res mask)
+	  (inst add res temp)))))
 
-      (emit-label done))))
 
 ;;; Multiply and Divide.
 
-(define-vop (fast-*/fixnum=>fixnum fast-fixnum-binop)
+(define-vop (fast-v8-*/fixnum=>fixnum fast-fixnum-binop)
   (:temporary (:scs (non-descriptor-reg)) temp)
   (:translate *)
   (:guard (backend-featurep :sparc-v8))
@@ -313,18 +342,40 @@
     (inst sra temp y 2)
     (inst smul r x temp)))
 
-(define-vop (fast-*/signed=>signed fast-signed-binop)
+(define-vop (fast-v8-*/signed=>signed fast-signed-binop)
   (:translate *)
   (:guard (backend-featurep :sparc-v8))
   (:generator 3
     (inst smul r x y)))
 
-(define-vop (fast-*/unsigned=>unsigned fast-unsigned-binop)
+(define-vop (fast-v8-*/unsigned=>unsigned fast-unsigned-binop)
   (:translate *)
   (:guard (backend-featurep :sparc-v8))
   (:generator 3
     (inst umul r x y)))
 
+;; The smul and umul instructions are deprecated on the Sparc V9.  Use
+;; mulx instead.
+(define-vop (fast-v9-*/fixnum=>fixnum fast-fixnum-binop)
+  (:temporary (:scs (non-descriptor-reg)) temp)
+  (:translate *)
+  (:guard (backend-featurep :sparc-64))
+  (:generator 4
+    (inst sra temp y 2)
+    (inst mulx r x temp)))
+
+(define-vop (fast-v9-*/signed=>signed fast-signed-binop)
+  (:translate *)
+  (:guard (backend-featurep :sparc-64))
+  (:generator 3
+    (inst mulx r x y)))
+
+(define-vop (fast-v9-*/unsigned=>unsigned fast-unsigned-binop)
+  (:translate *)
+  (:guard (backend-featurep :sparc-64))
+  (:generator 3
+    (inst mulx r x y)))
+
 
 ;;;; Binary conditional VOPs:
 
@@ -632,21 +683,41 @@
   Note: the lifetimes of MULTIPLICAND and RESULT-HIGH overlap."
   (declare (type tn multiplier result-high result-low)
 	   (type (or tn (signed-byte 13)) multiplicand))
-  (let ((label (gen-label)))
-    (inst wry multiplier)
-    (inst andcc result-high zero-tn)
-    ;; Note: we can't use the Y register until three insts after it's written.
-    (inst nop)
-    (inst nop)
-    (dotimes (i 32)
-      (inst mulscc result-high multiplicand))
-    (inst mulscc result-high zero-tn)
-    (inst cmp multiplicand)
-    (inst b :ge label)
-    (inst nop)
-    (inst add result-high multiplier)
-    (emit-label label)
-    (inst rdy result-low)))
+  ;; It seems that emit-multiply is only used to do an unsigned
+  ;; multiply, so the code only does an unsigned multiply.
+  (cond ((backend-featurep :sparc-64)
+	 ;; Take advantage of V9's 64-bit multiplier.
+	 ;;
+	 ;; Multiply the two numbers and put the result in
+	 ;; result-high.  Copy the low 32-bits to result-low.  Then
+	 ;; shift result-high so the high 32-bits end up in the low
+	 ;; 32-bits.
+	 (inst mulx result-high multiplier multiplicand)
+	 (inst move result-low result-high)
+	 (inst srax result-high 32))
+	((backend-featurep :sparc-v8)
+	 ;; V8 has a multiply instruction.  This should also work for
+	 ;; the V9, but umul and the Y register is deprecated on the
+	 ;; V9.
+	 (inst umul result-low multiplier multiplicand)
+	 (inst rdy result-high))
+	(t
+	 (let ((label (gen-label)))
+	   (inst wry multiplier)
+	   (inst andcc result-high zero-tn)
+	   ;; Note: we can't use the Y register until three insts
+	   ;; after it's written.
+	   (inst nop)
+	   (inst nop)
+	   (dotimes (i 32)
+	     (inst mulscc result-high multiplicand))
+	   (inst mulscc result-high zero-tn)
+	   (inst cmp multiplicand)
+	   (inst b :ge label)
+	   (inst nop)
+	   (inst add result-high multiplier)
+	   (emit-label label)
+	   (inst rdy result-low)))))
 
 (define-vop (bignum-mult-and-add-3-arg)
   (:translate bignum::%multiply-and-add)
@@ -713,7 +784,7 @@
   (:generator 1
     (inst sra digit fixnum 2)))
 
-(define-vop (bignum-floor)
+(define-vop (bignum-floor-v8)
   (:translate bignum::%floor)
   (:policy :fast-safe)
   (:args (div-high :scs (unsigned-reg) :target rem)
@@ -723,6 +794,7 @@
   (:results (quo :scs (unsigned-reg) :from (:argument 1))
 	    (rem :scs (unsigned-reg) :from (:argument 0)))
   (:result-types unsigned-num unsigned-num)
+  (:guard (not (backend-featurep :sparc-64)))
   (:generator 300
     (move rem div-high)
     (move quo div-low)
@@ -737,6 +809,28 @@
 	  (inst addx rem rem))))
     (inst not quo)))
 
+(define-vop (bignum-floor-v9)
+  (:translate bignum::%floor)
+  (:policy :fast-safe)
+  (:args (div-high :scs (unsigned-reg))
+	 (div-low :scs (unsigned-reg))
+	 (divisor :scs (unsigned-reg) :to (:result 1)))
+  (:arg-types unsigned-num unsigned-num unsigned-num)
+  (:temporary (:sc unsigned-reg :from (:argument 0)) dividend)
+  (:results (quo :scs (unsigned-reg))
+	    (rem :scs (unsigned-reg)))
+  (:result-types unsigned-num unsigned-num)
+  (:guard (backend-featurep :sparc-64))
+  (:generator 5
+    ;; Set dividend to be div-high and div-low	      
+    (inst sllx dividend div-high 32)
+    (inst add dividend div-low)
+    ;; Compute quotient
+    (inst udivx quo dividend divisor)
+    ;; Compute the remainder
+    (inst mulx rem quo divisor)
+    (inst sub rem dividend rem)))
+
 (define-vop (signify-digit)
   (:translate bignum::%fixnum-digit-with-correct-sign)
   (:policy :fast-safe)
