@@ -5,7 +5,7 @@
 ;;; Carnegie Mellon University, and has been placed in the public domain.
 ;;;
 (ext:file-comment
-  "$Header: /home/CVS-cmucl/src/compiler/sparc/float.lisp,v 1.24 1998/07/24 17:22:37 dtc Exp $")
+  "$Header: /home/CVS-cmucl/src/compiler/sparc/float.lisp,v 1.26 1999/11/19 14:55:47 dtc Exp $")
 ;;;
 ;;; **********************************************************************
 ;;;
@@ -790,7 +790,10 @@
       (:single (inst fcmps x y))
       (:double (inst fcmpd x y))
       (:long (inst fcmpx x y)))
-    (inst nop)
+    ;; The SPARC V9 doesn't need an instruction between a
+    ;; floating-point compare and a floating-point branch.
+    (unless (backend-featurep :sparc-v9)
+      (inst nop))
     (inst fb (if not-p nope yep) target)
     (inst nop)))
 
@@ -1269,7 +1272,9 @@
   (:results (y :scs (double-reg)))
   (:translate %sqrt)
   (:policy :fast-safe)
-  (:guard (backend-featurep :sparc-v7))
+  (:guard (or (backend-featurep :sparc-v7)
+	      (backend-featurep :sparc-v8)
+	      (backend-featurep :sparc-v9)))
   (:arg-types double-float)
   (:result-types double-float)
   (:note "inline float arithmetic")
