@@ -5,7 +5,7 @@
 ;;; Carnegie Mellon University, and has been placed in the public domain.
 ;;;
 (ext:file-comment
-  "$Header: /home/CVS-cmucl/src/compiler/sparc/type-vops.lisp,v 1.19 1998/07/24 17:22:38 dtc Exp $")
+  "$Header: /home/CVS-cmucl/src/compiler/sparc/type-vops.lisp,v 1.21 2000/01/10 14:46:12 dtc Exp $")
 ;;;
 ;;; **********************************************************************
 ;;; 
@@ -104,7 +104,7 @@
 (def-type-vops %instancep check-instance instance object-not-instance-error
   vm:instance-pointer-type)
 
-(def-type-vops bignump check-bigunm bignum
+(def-type-vops bignump check-bignum bignum
   object-not-bignum-error vm:bignum-type)
 
 (def-type-vops ratiop check-ratio ratio
@@ -264,9 +264,6 @@
 (def-type-vops funcallable-instance-p nil nil nil
   vm:funcallable-instance-header-type)
 
-(def-type-vops dylan::dylan-function-p nil nil nil
-  dylan-function-header-type)
-
 (def-type-vops array-header-p nil nil nil
   vm:simple-array-type vm:complex-string-type vm:complex-bit-vector-type
   vm:complex-vector-type vm:complex-array-type)
