@@ -7,7 +7,7 @@
 ;;; Scott Fahlman or slisp-group@cs.cmu.edu.
 ;;;
 (ext:file-comment
- "$Header: /home/CVS-cmucl/src/compiler/x86/arith.lisp,v 1.10 1998/02/19 19:34:38 dtc Exp $")
+ "$Header: /home/CVS-cmucl/src/compiler/x86/arith.lisp,v 1.12 2000/01/16 20:12:23 dtc Exp $")
 ;;;
 ;;; **********************************************************************
 ;;;
@@ -623,21 +623,20 @@
     ;; The result-type assures us that this shift will not overflow.
     (inst shl result :cl)))
 
-(define-vop (fast-ash-c)
+(define-vop (fast-ash-c/unsigned=>unsigned)
   (:translate ash)
   (:policy :fast-safe)
-  (:args (number :scs (signed-reg unsigned-reg) :target result
-		 :load-if (not (and (sc-is number signed-stack unsigned-stack)
-				    (sc-is result signed-stack unsigned-stack)
+  (:args (number :scs (unsigned-reg) :target result
+		 :load-if (not (and (sc-is number unsigned-stack)
+				    (sc-is result unsigned-stack)
 				    (location= number result)))))
   (:info amount)
-  (:arg-types (:or signed-num unsigned-num) (:constant integer))
-  (:results (result :scs (signed-reg unsigned-reg)
-		    :load-if (not
-			      (and (sc-is number signed-stack unsigned-stack)
-				   (sc-is result signed-stack unsigned-stack)
-				   (location= number result)))))
-  (:result-types (:or signed-num unsigned-num))
+  (:arg-types unsigned-num (:constant integer))
+  (:results (result :scs (unsigned-reg)
+		    :load-if (not (and (sc-is number unsigned-stack)
+				       (sc-is result unsigned-stack)
+				       (location= number result)))))
+  (:result-types unsigned-num)
   (:note "inline ASH")
   (:generator 3
     (cond ((and (= amount 1) (not (location= number result)))
@@ -652,29 +651,57 @@
 		  ;; We don't have to worry about overflow because of the
 		  ;; result type restriction.
 		  (inst shl result amount))
-		 ((sc-is number signed-reg signed-stack)
-		  ;; If the amount is greater than 31, only shift by 31.  We
-		  ;; have to do this because the shift instructions only look
-		  ;; at the low five bits of the result.
-		  (inst sar result (min 31 (- amount))))
 		 (t
 		  (inst shr result (min 31 (- amount)))))))))
 
-(define-vop (fast-ash-left)
+(define-vop (fast-ash-c/signed=>signed)
   (:translate ash)
-  (:args (number :scs (signed-reg unsigned-reg) :target result
-		 :load-if (not (and (sc-is number signed-stack unsigned-stack)
-				    (sc-is result signed-stack unsigned-stack)
+  (:policy :fast-safe)
+  (:args (number :scs (signed-reg) :target result
+		 :load-if (not (and (sc-is number signed-stack)
+				    (sc-is result signed-stack)
+				    (location= number result)))))
+  (:info amount)
+  (:arg-types signed-num (:constant integer))
+  (:results (result :scs (signed-reg)
+		    :load-if (not (and (sc-is number signed-stack)
+				       (sc-is result signed-stack)
+				       (location= number result)))))
+  (:result-types signed-num)
+  (:note "inline ASH")
+  (:generator 3
+    (cond ((and (= amount 1) (not (location= number result)))
+	   (inst lea result (make-ea :dword :index number :scale 2)))
+	  ((and (= amount 2) (not (location= number result)))
+	   (inst lea result (make-ea :dword :index number :scale 4)))
+	  ((and (= amount 3) (not (location= number result)))
+	   (inst lea result (make-ea :dword :index number :scale 8)))
+	  (t
+	   (move result number)
+	   (cond ((plusp amount)
+		  ;; We don't have to worry about overflow because of the
+		  ;; result type restriction.
+		  (inst shl result amount))
+		 (t
+		  ;; If the amount is greater than 31, only shift by 31.  We
+		  ;; have to do this because the shift instructions only look
+		  ;; at the low five bits of the result.
+		  (inst sar result (min 31 (- amount)))))))))
+
+(define-vop (fast-ash-left/unsigned=>unsigned)
+  (:translate ash)
+  (:args (number :scs (unsigned-reg) :target result
+		 :load-if (not (and (sc-is number unsigned-stack)
+				    (sc-is result unsigned-stack)
 				    (location= number result))))
 	 (amount :scs (unsigned-reg) :target ecx))
-  (:arg-types (:or signed-num unsigned-num) positive-fixnum)
+  (:arg-types unsigned-num positive-fixnum)
   (:temporary (:sc unsigned-reg :offset ecx-offset :from (:argument 1)) ecx)
-  (:results (result :scs (signed-reg unsigned-reg) :from (:argument 0)
-		    :load-if (not
-			      (and (sc-is number signed-stack unsigned-stack)
-				   (sc-is result signed-stack unsigned-stack)
-				   (location= number result)))))
-  (:result-types (:or signed-num unsigned-num))
+  (:results (result :scs (unsigned-reg) :from (:argument 0)
+		    :load-if (not (and (sc-is number unsigned-stack)
+				       (sc-is result unsigned-stack)
+				       (location= number result)))))
+  (:result-types unsigned-num)
   (:policy :fast-safe)
   (:note "inline ASH")
   (:generator 4
@@ -683,19 +710,41 @@
     ;; The result-type assures us that this shift will not overflow.
     (inst shl result :cl)))
 
-(define-vop (fast-ash)
+(define-vop (fast-ash-left/signed=>signed)
+  (:translate ash)
+  (:args (number :scs (signed-reg) :target result
+		 :load-if (not (and (sc-is number signed-stack)
+				    (sc-is result signed-stack)
+				    (location= number result))))
+	 (amount :scs (unsigned-reg) :target ecx))
+  (:arg-types signed-num positive-fixnum)
+  (:temporary (:sc unsigned-reg :offset ecx-offset :from (:argument 1)) ecx)
+  (:results (result :scs (signed-reg) :from (:argument 0)
+		    :load-if (not (and (sc-is number signed-stack)
+				       (sc-is result signed-stack)
+				       (location= number result)))))
+  (:result-types signed-num)
+  (:policy :fast-safe)
+  (:note "inline ASH")
+  (:generator 4
+    (move result number)
+    (move ecx amount)
+    ;; The result-type assures us that this shift will not overflow.
+    (inst shl result :cl)))
+
+(define-vop (fast-ash/unsigned=>unsigned)
   (:translate ash)
   (:policy :fast-safe)
-  (:args (number :scs (signed-reg unsigned-reg) :target result)
+  (:args (number :scs (unsigned-reg) :target result)
 	 (amount :scs (signed-reg) :target ecx))
-  (:arg-types (:or signed-num unsigned-num) signed-num)
-  (:results (result :scs (signed-reg unsigned-reg) :from (:argument 0)))
-  (:result-types (:or signed-num unsigned-num))
+  (:arg-types unsigned-num signed-num)
+  (:results (result :scs (unsigned-reg) :from (:argument 0)))
+  (:result-types unsigned-num)
   (:temporary (:sc signed-reg :offset ecx-offset :from (:argument 1)) ecx)
   (:note "inline ASH")
   (:generator 5
     (move result number)
-     (move ecx amount)
+    (move ecx amount)
     (inst or ecx ecx)
     (inst jmp :ns positive)
     (inst neg ecx)
@@ -703,9 +752,7 @@
     (inst jmp :be okay)
     (inst mov ecx 31)
     OKAY
-    (sc-case number
-      (signed-reg (inst sar result :cl))
-      (unsigned-reg (inst shr result :cl)))
+    (inst shr result :cl)
     (inst jmp done)
       
     POSITIVE
@@ -714,6 +761,34 @@
       
     DONE))
 
+(define-vop (fast-ash/signed=>signed)
+  (:translate ash)
+  (:policy :fast-safe)
+  (:args (number :scs (signed-reg) :target result)
+	 (amount :scs (signed-reg) :target ecx))
+  (:arg-types signed-num signed-num)
+  (:results (result :scs (signed-reg) :from (:argument 0)))
+  (:result-types signed-num)
+  (:temporary (:sc signed-reg :offset ecx-offset :from (:argument 1)) ecx)
+  (:note "inline ASH")
+  (:generator 5
+    (move result number)
+    (move ecx amount)
+    (inst or ecx ecx)
+    (inst jmp :ns positive)
+    (inst neg ecx)
+    (inst cmp ecx 31)
+    (inst jmp :be okay)
+    (inst mov ecx 31)
+    OKAY
+    (inst sar result :cl)
+    (inst jmp done)
+      
+    POSITIVE
+    ;; The result-type assures us that this shift will not overflow.
+    (inst shl result :cl)
+      
+    DONE))
 
 
 ;;; note documentation for this function is wrong - rtfm
@@ -924,7 +999,7 @@
   (:info target not-p y)
   (:translate eql)
   (:generator 2
-    (cond ((and (sc-is x any-reg) (zerop y))
+    (cond ((and (sc-is x any-reg descriptor-reg) (zerop y))
 	   (inst test x x))  ; Smaller instruction
 	  (t
 	   (inst cmp x (fixnum y))))
