@@ -7,7 +7,7 @@
 ;;; Scott Fahlman or slisp-group@cs.cmu.edu.
 ;;;
 (ext:file-comment
-  "$Header: /home/CVS-cmucl/src/compiler/x86/insts.lisp,v 1.16 1998/02/24 09:59:21 dtc Exp $")
+  "$Header: /home/CVS-cmucl/src/compiler/x86/insts.lisp,v 1.19 1999/11/11 16:12:30 dtc Exp $")
 ;;;
 ;;; **********************************************************************
 ;;;
@@ -1152,7 +1152,7 @@
      ((integerp src)
       (cond ((and (not (eq size :byte)) (<= -128 src 127))
 	     (emit-byte segment #b10000011)
-	     (emit-ea segment dst opcode)
+	     (emit-ea segment dst opcode allow-constants)
 	     (emit-byte segment src))
 	    ((accumulator-p dst)
 	     (emit-byte segment
@@ -1164,7 +1164,7 @@
 	     (emit-sized-immediate segment size src))
 	    (t
 	     (emit-byte segment (if (eq size :byte) #b10000000 #b10000001))
-	     (emit-ea segment dst opcode)
+	     (emit-ea segment dst opcode allow-constants)
 	     (emit-sized-immediate segment size src))))
      ((register-p src)
       (emit-byte segment
@@ -2500,6 +2500,14 @@
   (:emitter
    (emit-byte segment #b11011101)
    (emit-fp-op segment dest #b000)))
+;;;
+;;; Free fp register and pop the stack.
+;;;
+(define-instruction ffreep (segment dest)
+  (:printer floating-point-fp ((op '(#b111 #b000))))
+  (:emitter 
+   (emit-byte segment #b11011111)
+   (emit-fp-op segment dest #b000)))
 
 (define-instruction fabs (segment)
   (:printer floating-point-no ((op #b00001)))
@@ -2621,6 +2629,18 @@
    (emit-byte segment #b11011110)
    (emit-byte segment #b11011001)))
 
+;;;
+;;; Compare ST(i) to ST0 and update the flags.
+;;;
+;;; Intel syntal: FCOMI ST, ST(i)
+;;;
+(define-instruction fcomi (segment src)
+  (:printer floating-point ((op '(#b011 #b110))))
+  (:emitter
+   (assert (fp-reg-tn-p src))
+   (emit-byte segment #b11011011)
+   (emit-fp-op segment src #b110)))
+
 ;;;
 ;;; Unordered comparison
 ;;;
@@ -2631,6 +2651,18 @@
    (assert (fp-reg-tn-p src))
    (emit-byte segment #b11011101)
    (emit-fp-op segment src #b100)))
+;;;
+;;; Unordered compare ST(i) to ST0 and update the flags.
+;;;
+;;; Intel syntal: FUCOMI ST, ST(i)
+;;;
+(define-instruction fucomi (segment src)
+  ;; XX Printer conflicts with fldl due to the mod bits.
+  #+nil (:printer floating-point ((op '(#b011 #b101))))
+  (:emitter
+   (assert (fp-reg-tn-p src))
+   (emit-byte segment #b11011011)
+   (emit-fp-op segment src #b101)))
 
 (define-instruction ftst (segment)
   (:printer floating-point-no ((op #b00100)))
