@@ -7,7 +7,7 @@
 ;;; Scott Fahlman or slisp-group@cs.cmu.edu.
 ;;;
 (ext:file-comment
- "$Header: /home/CVS-cmucl/src/compiler/x86/print.lisp,v 1.3 1998/02/19 19:35:03 dtc Exp $")
+ "$Header: /home/CVS-cmucl/src/compiler/x86/print.lisp,v 1.4 1999/12/04 16:06:08 dtc Exp $")
 ;;;
 ;;; **********************************************************************
 ;;;
@@ -22,8 +22,7 @@
 (define-vop (print)
   (:args (object :scs (descriptor-reg any-reg)))
   (:temporary (:sc unsigned-reg :offset eax-offset :target result
-		   :from :eval :to (:result 0))
-	      eax)
+		   :from :eval :to :result) eax)
   (:results (result :scs (descriptor-reg)))
   (:save-p t)
   (:generator 100
