@@ -1,7 +1,4 @@
 (in-package "HI")
-#+cmu
-(ext:file-comment
-  "$Header$")
 
 (defun %sp-byte-blt (src start dest dstart end)
   (%primitive byte-blt src start dest dstart end))
