@@ -1,4 +1,4 @@
-/* $Header: /home/CVS-cmucl/src/lisp/print.c,v 1.9 1998/06/03 02:24:11 dtc Exp $ */
+/* $Header: /home/CVS-cmucl/src/lisp/print.c,v 1.11 1999/02/20 15:54:45 pw Exp $ */
 #include <stdio.h>
 
 #include "print.h"
@@ -412,8 +412,13 @@ static void print_otherptr(lispobj obj)
         int count, type, index;
         char *cptr, buffer[16];
 
+#ifndef alpha
 	ptr = (unsigned long *) PTR(obj);
 	if (ptr == (unsigned long *) NULL) {
+#else
+	ptr = (u32 *) PTR(obj);
+	if (ptr == (u32 *) NULL) {
+#endif
 		printf(" (NULL Pointer)");
 		return;
 	}
