@@ -3,7 +3,11 @@
 ;;; **********************************************************************
 ;;; This code was written as part of the CMU Common Lisp project at
 ;;; Carnegie Mellon University, and has been placed in the public domain.
-;;; If you want to use this code or any part of CMU Common Lisp, please contact;;; Scott Fahlman or slisp-group@cs.cmu.edu.
+;;; If you want to use this code or any part of CMU Common Lisp, please
+;;; contact Scott Fahlman or slisp-group@cs.cmu.edu.
+;;;
+(ext:file-comment
+  "$Header: /home/CVS-cmucl/src/motif/lisp/prototypes.lisp,v 1.9 1998/12/20 04:22:54 dtc Exp $")
 ;;;
 ;;; **********************************************************************
 ;;;
@@ -12,9 +16,6 @@
 ;;; This file contains the prototyping code for RPC requests between the
 ;;; Lisp client and the C server.
 ;;;
-#+cmu
-(ext:file-comment
-  "$Header$")
 
 (in-package "TOOLKIT")
 
