@@ -18,8 +18,8 @@
 ;;;
 
 (ext:file-comment
-  "$Header$")
-
+  "$Header: /home/CVS-cmucl/src/pcl/extensions.lisp,v 1.3 1999/05/30 23:13:58 pw Exp $")
+;;;
 
 (in-package 'pcl)
 
@@ -491,10 +491,6 @@
             variable-accessors))
        ,@body))))
 
-
-#-(or KCL IBCL)
 (export *extensions-exports* *the-pcl-package*)
 
-#+(or KCL IBCL)
-(mapc 'export (list *extensions-exports*) (list *the-pcl-package*))
 
