@@ -23,12 +23,12 @@
 ;;;
 ;;; Suggestions, comments and requests for improvements are also welcome.
 ;;; *************************************************************************
-;;; 
-;;; Original source {pooh/n}<pooh>vanmelle>lisp>iterate;4 created 27-Sep-88 12:35:33
+;;;
 
 (ext:file-comment
-  "$Header$")
-
+  "$Header: /home/CVS-cmucl/src/pcl/iterate.lisp,v 1.7 1999/05/30 23:14:01 pw Exp $")
+;;; 
+;;; Original source {pooh/n}<pooh>vanmelle>lisp>iterate;4 created 27-Sep-88 12:35:33
 
 (defpackage "ITERATE" (:use :common-lisp :walker)
   (:export "ITERATE" "ITERATE*" "GATHERING" "GATHER" "WITH-GATHERING"
@@ -298,16 +298,7 @@ NIL => never; :USER => those resulting from user code; T => always, even if it's
                  (generator (second clause)))
                 (setq
                  let-bindings
-                 (list (list gvar
-                             (cond
-			      #-cmu ; Python thinks this is unreachable.
-			      (leftover-body
-                                               ; Have to use this up
-                               `(progn ,@(prog1 leftover-body (setq 
-                                                                  leftover-body
-                                                                    nil))
-                                       generator))
-                              (t generator)))))
+                 (list (list gvar generator)))
                 (setq let-body `(funcall ,gvar #'(lambda nil ,finish-form)))))
            (push (mv-setq (copy-list vars)
                         let-body)
