@@ -26,7 +26,8 @@
 ;;;
 
 (ext:file-comment
-  "$Header$")
+  "$Header: /home/CVS-cmucl/src/pcl/methods.lisp,v 1.13 1999/05/30 23:14:03 pw Exp $")
+;;;
 
 (in-package :pcl)
 
@@ -1032,7 +1033,7 @@
 		  (mec-all-class-lists (method-specializers method) precompute-p))))
       cache)))
 
-#+cmu
+
 (defmacro class-test (arg class)
   (cond ((eq class *the-class-t*)
 	 't)
@@ -1044,9 +1045,6 @@
 	 `(std-instance-p ,arg))
 	((eq class *the-class-funcallable-standard-object*)
 	 `(fsc-instance-p ,arg))
-	#-cmu17
-	((eq class *the-class-structure-object*)
-	 `(memq ',class (class-precedence-list (class-of ,arg))))
 	;; TYPEP is now sometimes faster than doing memq of the cpl
 	(t
 	 `(typep ,arg ',(class-name class)))))
@@ -1185,8 +1183,6 @@
 	    new-type
 	    `(and ,new-type ,@so-far)))))
 
-#+lcl3.0 (dont-use-production-compiler)
-
 (defun generate-discrimination-net-internal 
     (gf methods types methods-function test-function type-function)
   (let* ((arg-info (gf-arg-info gf))
@@ -1245,8 +1241,6 @@
 					   (do-if t) (do-if nil))))))))))
       (do-column precedence methods ()))))
 
-#+lcl3.0 (use-previous-compiler)
-
 (defun compute-secondary-dispatch-function (generic-function net &optional 
 					    method-alist wrappers)
   (function-funcall (compute-secondary-dispatch-function1 generic-function net)
@@ -1389,10 +1383,9 @@
 			(make-fast-method-call-lambda-list metatypes applyp))))
       (multiple-value-bind
 	  (cfunction constants)
-	  (get-function1 `(#+cmu ,(if function-p
-				      'kernel:instance-lambda
-				      'lambda)
-			   #-cmu lambda
+	  (get-function1 `(,(if function-p
+				'kernel:instance-lambda
+				'lambda)			   
 			   ,arglist
 				 ,@(unless function-p
 				     `((declare (ignore .pv-cell.
