@@ -1,6 +1,3 @@
-#+cmu
-(ext:file-comment
-  "$Header$")
 (in-package "PCL")
 (unless (find-package "SLOT-ACCESSOR-NAME")
   (make-package "SLOT-ACCESSOR-NAME" :use nil))
